@@ -167,7 +167,7 @@
     <message>
         <location filename="../devicewidget.cc" line="227"/>
         <source>Sorry, but device renaming is not supported.</source>
-        <translation type="unfinished"></translation>
+        <translation>ਅਫ਼ਸੋਸ ਹੈ ਪਰ ਡਿਵਾਈਸ ਦੇ ਨਾਂ ਬਦਲਣ ਲਈ ਸਹਾਇਕ ਨਹੀਂ ਹੈ।</translation>
     </message>
     <message>
         <location filename="../devicewidget.cc" line="228"/>
@@ -177,7 +177,7 @@
     <message>
         <location filename="../devicewidget.cc" line="234"/>
         <source>Rename device %1 to:</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 ਡਿਵਾਈਸ ਦਾ ਨਾਂ ਬਦਲੋ:</translation>
     </message>
     <message>
         <location filename="../devicewidget.cc" line="241"/>
@@ -521,7 +521,7 @@
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="607"/>
-        <location filename="../pavucontrol.cc" line="664"/>
+        <location filename="../pavucontrol.cc" line="663"/>
         <source>PulseAudio Volume Control</source>
         <translation>ਪਲੱਸਆਡੀਓ ਵਾਲੀਅਮ ਕੰਟਰੋਲ</translation>
     </message>
@@ -531,22 +531,22 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="672"/>
+        <location filename="../pavucontrol.cc" line="671"/>
         <source>Select a specific tab on load.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="675"/>
+        <location filename="../pavucontrol.cc" line="674"/>
         <source>Retry forever if pa quits (every 5 seconds).</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="678"/>
+        <location filename="../pavucontrol.cc" line="677"/>
         <source>Maximize the window.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="703"/>
+        <location filename="../pavucontrol.cc" line="702"/>
         <source>Fatal Error: Unable to connect to PulseAudio</source>
         <translation type="unfinished"></translation>
     </message>
@@ -691,12 +691,12 @@
     <message>
         <location filename="../streamwidget.ui" line="14"/>
         <source>Form</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ਫਾਰਮ</translation>
     </message>
     <message>
         <location filename="../streamwidget.ui" line="32"/>
         <source>Device Title</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ਡਿਵਾਈਸ ਦਾ ਨਾਂ</translation>
     </message>
     <message>
         <location filename="../streamwidget.ui" line="52"/>
@@ -711,12 +711,12 @@
     <message>
         <location filename="../streamwidget.ui" line="66"/>
         <source>Mute audio</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ਆਡੀਓ ਮੌਨ ਕਰੋ</translation>
     </message>
     <message>
         <location filename="../streamwidget.ui" line="79"/>
         <source>Lock channels together</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ਚੈਨਲਾਂ ਨੂੰ ਇਕੱਠੇ ਲਾਕ ਕਰੋ</translation>
     </message>
     <message>
         <location filename="../streamwidget.cc" line="34"/>
